# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'crystalUI.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets
import os
fn = os.path.join(os.path.dirname(__file__), "crystal-icon.png")

class Ui_Crystal(object):
    def setupUi(self, Crystal):
        Crystal.setObjectName("Crystal")
        Crystal.resize(1222, 796)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(fn), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Crystal.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(Crystal)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_11 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_11.setObjectName("gridLayout_11")
        self.mplvl = QtWidgets.QGridLayout()
        self.mplvl.setObjectName("mplvl")
        self.gridLayout_11.addLayout(self.mplvl, 0, 0, 1, 1)
        self.groupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox.setMaximumSize(QtCore.QSize(400, 16777215))
        self.groupBox.setTitle("")
        self.groupBox.setObjectName("groupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBox_2 = QtWidgets.QGroupBox(self.groupBox)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.groupBox_2.sizePolicy().hasHeightForWidth())
        self.groupBox_2.setSizePolicy(sizePolicy)
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.alphabetagamma_label = QtWidgets.QLabel(self.groupBox_2)
        self.alphabetagamma_label.setObjectName("alphabetagamma_label")
        self.gridLayout_2.addWidget(self.alphabetagamma_label, 1, 0, 1, 1)
        self.alphabetagamma_entry = QtWidgets.QLineEdit(self.groupBox_2)
        self.alphabetagamma_entry.setObjectName("alphabetagamma_entry")
        self.gridLayout_2.addWidget(self.alphabetagamma_entry, 1, 1, 1, 1)
        self.abc_entry = QtWidgets.QLineEdit(self.groupBox_2)
        self.abc_entry.setObjectName("abc_entry")
        self.gridLayout_2.addWidget(self.abc_entry, 0, 1, 1, 1)
        self.abc_label = QtWidgets.QLabel(self.groupBox_2)
        self.abc_label.setObjectName("abc_label")
        self.gridLayout_2.addWidget(self.abc_label, 0, 0, 1, 1)
        self.changeStruct_button = QtWidgets.QPushButton(self.groupBox_2)
        self.changeStruct_button.setObjectName("changeStruct_button")
        self.gridLayout_2.addWidget(self.changeStruct_button, 2, 0, 1, 2)
        self.gridLayout.addWidget(self.groupBox_2, 0, 0, 1, 1)
        self.groupBox_3 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_3.setObjectName("groupBox_3")
        self.gridLayout_3 = QtWidgets.QGridLayout(self.groupBox_3)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.label_2 = QtWidgets.QLabel(self.groupBox_3)
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 2, 0, 1, 1)
        self.label = QtWidgets.QLabel(self.groupBox_3)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 0, 1, 1)
        self.layers_entry = QtWidgets.QLineEdit(self.groupBox_3)
        self.layers_entry.setObjectName("layers_entry")
        self.gridLayout_3.addWidget(self.layers_entry, 2, 2, 1, 1)
        self.plane_entry = QtWidgets.QLineEdit(self.groupBox_3)
        self.plane_entry.setObjectName("plane_entry")
        self.gridLayout_3.addWidget(self.plane_entry, 0, 1, 1, 2)
        self.size_entry = QtWidgets.QLineEdit(self.groupBox_3)
        self.size_entry.setObjectName("size_entry")
        self.gridLayout_3.addWidget(self.size_entry, 1, 2, 1, 1)
        self.label_3 = QtWidgets.QLabel(self.groupBox_3)
        self.label_3.setObjectName("label_3")
        self.gridLayout_3.addWidget(self.label_3, 1, 0, 1, 1)
        self.gridLayout.addWidget(self.groupBox_3, 0, 1, 1, 1)
        self.groupBox_4 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_4.setTitle("")
        self.groupBox_4.setObjectName("groupBox_4")
        self.gridLayout_4 = QtWidgets.QGridLayout(self.groupBox_4)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.label_6 = QtWidgets.QLabel(self.groupBox_4)
        self.label_6.setObjectName("label_6")
        self.gridLayout_4.addWidget(self.label_6, 2, 0, 1, 1)
        self.markers_entry = QtWidgets.QLineEdit(self.groupBox_4)
        self.markers_entry.setObjectName("markers_entry")
        self.gridLayout_4.addWidget(self.markers_entry, 2, 1, 1, 1)
        self.square_box = QtWidgets.QCheckBox(self.groupBox_4)
        self.square_box.setObjectName("square_box")
        self.gridLayout_4.addWidget(self.square_box, 3, 0, 1, 2)
        self.labels_box = QtWidgets.QCheckBox(self.groupBox_4)
        self.labels_box.setObjectName("labels_box")
        self.gridLayout_4.addWidget(self.labels_box, 4, 0, 1, 2)
        self.atoms_box = QtWidgets.QCheckBox(self.groupBox_4)
        self.atoms_box.setObjectName("atoms_box")
        self.gridLayout_4.addWidget(self.atoms_box, 5, 0, 1, 2)
        self.calculate_button = QtWidgets.QPushButton(self.groupBox_4)
        self.calculate_button.setObjectName("calculate_button")
        self.gridLayout_4.addWidget(self.calculate_button, 0, 0, 1, 2)
        self.draw_button = QtWidgets.QPushButton(self.groupBox_4)
        self.draw_button.setObjectName("draw_button")
        self.gridLayout_4.addWidget(self.draw_button, 1, 0, 1, 2)
        self.gridLayout.addWidget(self.groupBox_4, 1, 0, 1, 1)
        self.groupBox_5 = QtWidgets.QGroupBox(self.groupBox)
        self.groupBox_5.setObjectName("groupBox_5")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.groupBox_5)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.label_5 = QtWidgets.QLabel(self.groupBox_5)
        self.label_5.setObjectName("label_5")
        self.gridLayout_5.addWidget(self.label_5, 5, 0, 1, 1)
        self.dsc_box = QtWidgets.QCheckBox(self.groupBox_5)
        self.dsc_box.setObjectName("dsc_box")
        self.gridLayout_5.addWidget(self.dsc_box, 0, 0, 1, 1)
        self.label_4 = QtWidgets.QLabel(self.groupBox_5)
        self.label_4.setObjectName("label_4")
        self.gridLayout_5.addWidget(self.label_4, 1, 0, 1, 1)
        self.angle_entry = QtWidgets.QLineEdit(self.groupBox_5)
        self.angle_entry.setObjectName("angle_entry")
        self.gridLayout_5.addWidget(self.angle_entry, 1, 1, 1, 1)
        self.coincidence_box = QtWidgets.QCheckBox(self.groupBox_5)
        self.coincidence_box.setObjectName("coincidence_box")
        self.gridLayout_5.addWidget(self.coincidence_box, 3, 0, 1, 2)
        self.layers_box = QtWidgets.QCheckBox(self.groupBox_5)
        self.layers_box.setObjectName("layers_box")
        self.gridLayout_5.addWidget(self.layers_box, 4, 0, 1, 2)
        self.precision_entry = QtWidgets.QLineEdit(self.groupBox_5)
        self.precision_entry.setObjectName("precision_entry")
        self.gridLayout_5.addWidget(self.precision_entry, 5, 1, 1, 1)
        self.gridLayout.addWidget(self.groupBox_5, 1, 1, 1, 1)
        self.gridLayout_11.addWidget(self.groupBox, 0, 1, 1, 1)
        Crystal.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(Crystal)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1222, 22))
        self.menubar.setObjectName("menubar")
        self.menuSave = QtWidgets.QMenu(self.menubar)
        self.menuSave.setObjectName("menuSave")
        self.menuStructure = QtWidgets.QMenu(self.menubar)
        self.menuStructure.setObjectName("menuStructure")
        Crystal.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(Crystal)
        self.statusbar.setObjectName("statusbar")
        Crystal.setStatusBar(self.statusbar)
        self.actionSave_figure = QtWidgets.QAction(Crystal)
        self.actionSave_figure.setObjectName("actionSave_figure")
        self.actionCalculate_Schmid_factor = QtWidgets.QAction(Crystal)
        self.actionCalculate_Schmid_factor.setObjectName("actionCalculate_Schmid_factor")
        self.actionCalculate_angle = QtWidgets.QAction(Crystal)
        self.actionCalculate_angle.setObjectName("actionCalculate_angle")
        self.actionCalculate_xyz = QtWidgets.QAction(Crystal)
        self.actionCalculate_xyz.setObjectName("actionCalculate_xyz")
        self.actionCalculate_apparent_width = QtWidgets.QAction(Crystal)
        self.actionCalculate_apparent_width.setObjectName("actionCalculate_apparent_width")
        self.actionPlanes = QtWidgets.QAction(Crystal)
        self.actionPlanes.setObjectName("actionPlanes")
        self.actionProj_directions = QtWidgets.QAction(Crystal)
        self.actionProj_directions.setObjectName("actionProj_directions")
        self.actionPlane_cone = QtWidgets.QAction(Crystal)
        self.actionPlane_cone.setObjectName("actionPlane_cone")
        self.actionCalculate_intersections = QtWidgets.QAction(Crystal)
        self.actionCalculate_intersections.setObjectName("actionCalculate_intersections")
        self.actionHkl_uvw = QtWidgets.QAction(Crystal)
        self.actionHkl_uvw.setObjectName("actionHkl_uvw")
        self.actionPlot_Kikuchi_lines = QtWidgets.QAction(Crystal)
        self.actionPlot_Kikuchi_lines.setObjectName("actionPlot_Kikuchi_lines")
        self.menuSave.addAction(self.actionSave_figure)
        self.menubar.addAction(self.menuSave.menuAction())
        self.menubar.addAction(self.menuStructure.menuAction())

        self.retranslateUi(Crystal)
        QtCore.QMetaObject.connectSlotsByName(Crystal)
        Crystal.setTabOrder(self.abc_entry, self.alphabetagamma_entry)
        Crystal.setTabOrder(self.alphabetagamma_entry, self.plane_entry)
        Crystal.setTabOrder(self.plane_entry, self.size_entry)
        Crystal.setTabOrder(self.size_entry, self.layers_entry)
        Crystal.setTabOrder(self.layers_entry, self.changeStruct_button)
        Crystal.setTabOrder(self.changeStruct_button, self.calculate_button)
        Crystal.setTabOrder(self.calculate_button, self.draw_button)
        Crystal.setTabOrder(self.draw_button, self.markers_entry)
        Crystal.setTabOrder(self.markers_entry, self.square_box)
        Crystal.setTabOrder(self.square_box, self.labels_box)
        Crystal.setTabOrder(self.labels_box, self.atoms_box)
        Crystal.setTabOrder(self.atoms_box, self.dsc_box)
        Crystal.setTabOrder(self.dsc_box, self.angle_entry)
        Crystal.setTabOrder(self.angle_entry, self.coincidence_box)
        Crystal.setTabOrder(self.coincidence_box, self.layers_box)
        Crystal.setTabOrder(self.layers_box, self.precision_entry)

    def retranslateUi(self, Crystal):
        _translate = QtCore.QCoreApplication.translate
        Crystal.setWindowTitle(_translate("Crystal", "Crystal"))
        self.groupBox_2.setTitle(_translate("Crystal", "Crystal Parameters"))
        self.alphabetagamma_label.setText(_translate("Crystal", "<p>&alpha;, &beta;, &gamma;</p>"))
        self.abc_label.setText(_translate("Crystal", "a,b,c"))
        self.changeStruct_button.setText(_translate("Crystal", "Change structure"))
        self.groupBox_3.setTitle(_translate("Crystal", "Layers"))
        self.label_2.setText(_translate("Crystal", "Layers numb."))
        self.label.setText(_translate("Crystal", "Plane"))
        self.label_3.setText(_translate("Crystal", "Size"))
        self.label_6.setText(_translate("Crystal", "Marker size"))
        self.square_box.setText(_translate("Crystal", "Square/circle"))
        self.labels_box.setText(_translate("Crystal", "Atom positions"))
        self.atoms_box.setText(_translate("Crystal", "Atom type"))
        self.calculate_button.setText(_translate("Crystal", "Calculate"))
        self.draw_button.setText(_translate("Crystal", "Draw"))
        self.groupBox_5.setTitle(_translate("Crystal", "Dichromatic"))
        self.label_5.setText(_translate("Crystal", "Precision"))
        self.dsc_box.setText(_translate("Crystal", "enable"))
        self.label_4.setText(_translate("Crystal", " angle"))
        self.coincidence_box.setText(_translate("Crystal", "coincidence"))
        self.layers_box.setText(_translate("Crystal", "layers"))
        self.menuSave.setTitle(_translate("Crystal", "Save"))
        self.menuStructure.setTitle(_translate("Crystal", "Structure"))
        self.actionSave_figure.setText(_translate("Crystal", "Save figure"))
        self.actionCalculate_Schmid_factor.setText(_translate("Crystal", "calculate Schmid factor"))
        self.actionCalculate_angle.setText(_translate("Crystal", "Calculate angle"))
        self.actionCalculate_xyz.setText(_translate("Crystal", "calculate xyz directions"))
        self.actionCalculate_apparent_width.setText(_translate("Crystal", "Calculate apparent width"))
        self.actionPlanes.setText(_translate("Crystal", "planes"))
        self.actionProj_directions.setText(_translate("Crystal", "proj. directions"))
        self.actionPlane_cone.setText(_translate("Crystal", "plane-cone"))
        self.actionCalculate_intersections.setText(_translate("Crystal", "Calculate intersections"))
        self.actionHkl_uvw.setText(_translate("Crystal", "hkl <> uvw"))
        self.actionPlot_Kikuchi_lines.setText(_translate("Crystal", "plot Kikuchi lines or diffraction pattern"))
