# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'ipfUI.ui'
#
# Created by: PyQt5 UI code generator 5.15.2
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_IPF(object):
    def setupUi(self, IPF):
        IPF.setObjectName("IPF")
        IPF.resize(707, 786)
        self.gridLayout_2 = QtWidgets.QGridLayout(IPF)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.plane_comboBox = QtWidgets.QComboBox(IPF)
        self.plane_comboBox.setEditable(True)
        self.plane_comboBox.setObjectName("plane_comboBox")
        self.gridLayout_2.addWidget(self.plane_comboBox, 8, 0, 1, 5)
        self.pole_comboBox = QtWidgets.QComboBox(IPF)
        self.pole_comboBox.setEditable(True)
        self.pole_comboBox.setObjectName("pole_comboBox")
        self.gridLayout_2.addWidget(self.pole_comboBox, 7, 0, 1, 5)
        self.red_Button = QtWidgets.QRadioButton(IPF)
        self.red_Button.setObjectName("red_Button")
        self.gridLayout_2.addWidget(self.red_Button, 11, 1, 1, 1)
        self.blue_Button = QtWidgets.QRadioButton(IPF)
        self.blue_Button.setObjectName("blue_Button")
        self.gridLayout_2.addWidget(self.blue_Button, 11, 0, 1, 1)
        self.Show_label_checkBox = QtWidgets.QCheckBox(IPF)
        self.Show_label_checkBox.setObjectName("Show_label_checkBox")
        self.gridLayout_2.addWidget(self.Show_label_checkBox, 6, 6, 1, 1)
        self.add_pole_button = QtWidgets.QPushButton(IPF)
        self.add_pole_button.setObjectName("add_pole_button")
        self.gridLayout_2.addWidget(self.add_pole_button, 7, 5, 1, 1)
        self.remove_pole_button = QtWidgets.QPushButton(IPF)
        self.remove_pole_button.setObjectName("remove_pole_button")
        self.gridLayout_2.addWidget(self.remove_pole_button, 7, 6, 1, 1)
        self.remove_plane_button = QtWidgets.QPushButton(IPF)
        self.remove_plane_button.setObjectName("remove_plane_button")
        self.gridLayout_2.addWidget(self.remove_plane_button, 8, 6, 1, 1)
        self.add_plane_button = QtWidgets.QPushButton(IPF)
        self.add_plane_button.setObjectName("add_plane_button")
        self.gridLayout_2.addWidget(self.add_plane_button, 8, 5, 1, 1)
        self.refresh_Button = QtWidgets.QPushButton(IPF)
        self.refresh_Button.setObjectName("refresh_Button")
        self.gridLayout_2.addWidget(self.refresh_Button, 6, 5, 1, 1)
        self.mplvl = QtWidgets.QGridLayout()
        self.mplvl.setObjectName("mplvl")
        self.gridLayout_2.addLayout(self.mplvl, 1, 0, 1, 7)
        self.green_Button = QtWidgets.QRadioButton(IPF)
        self.green_Button.setObjectName("green_Button")
        self.gridLayout_2.addWidget(self.green_Button, 11, 2, 1, 1)
        self.draw_button = QtWidgets.QPushButton(IPF)
        self.draw_button.setObjectName("draw_button")
        self.gridLayout_2.addWidget(self.draw_button, 6, 0, 1, 5)
        self.pole_entry = QtWidgets.QLineEdit(IPF)
        self.pole_entry.setObjectName("pole_entry")
        self.gridLayout_2.addWidget(self.pole_entry, 10, 0, 1, 2)
        self.PF_button = QtWidgets.QPushButton(IPF)
        self.PF_button.setObjectName("PF_button")
        self.gridLayout_2.addWidget(self.PF_button, 10, 2, 1, 1)
        self.IPF_button = QtWidgets.QPushButton(IPF)
        self.IPF_button.setObjectName("IPF_button")
        self.gridLayout_2.addWidget(self.IPF_button, 10, 3, 1, 1)
        self.import_button = QtWidgets.QPushButton(IPF)
        self.import_button.setObjectName("import_button")
        self.gridLayout_2.addWidget(self.import_button, 10, 4, 1, 1)
        self.current_checkBox = QtWidgets.QCheckBox(IPF)
        self.current_checkBox.setObjectName("current_checkBox")
        self.gridLayout_2.addWidget(self.current_checkBox, 10, 5, 1, 1)
        self.data_label = QtWidgets.QLabel(IPF)
        self.data_label.setText("")
        self.data_label.setObjectName("data_label")
        self.gridLayout_2.addWidget(self.data_label, 11, 4, 1, 2)

        self.retranslateUi(IPF)
        QtCore.QMetaObject.connectSlotsByName(IPF)
        IPF.setTabOrder(self.draw_button, self.refresh_Button)
        IPF.setTabOrder(self.refresh_Button, self.Show_label_checkBox)
        IPF.setTabOrder(self.Show_label_checkBox, self.pole_comboBox)
        IPF.setTabOrder(self.pole_comboBox, self.add_pole_button)
        IPF.setTabOrder(self.add_pole_button, self.remove_pole_button)
        IPF.setTabOrder(self.remove_pole_button, self.plane_comboBox)
        IPF.setTabOrder(self.plane_comboBox, self.add_plane_button)
        IPF.setTabOrder(self.add_plane_button, self.remove_plane_button)
        IPF.setTabOrder(self.remove_plane_button, self.pole_entry)
        IPF.setTabOrder(self.pole_entry, self.PF_button)
        IPF.setTabOrder(self.PF_button, self.IPF_button)
        IPF.setTabOrder(self.IPF_button, self.import_button)
        IPF.setTabOrder(self.import_button, self.blue_Button)
        IPF.setTabOrder(self.blue_Button, self.red_Button)
        IPF.setTabOrder(self.red_Button, self.green_Button)

    def retranslateUi(self, IPF):
        _translate = QtCore.QCoreApplication.translate
        IPF.setWindowTitle(_translate("IPF", "PF/IPF"))
        self.red_Button.setText(_translate("IPF", "Red"))
        self.blue_Button.setText(_translate("IPF", "Blue"))
        self.Show_label_checkBox.setText(_translate("IPF", "Show labels"))
        self.add_pole_button.setText(_translate("IPF", "Add Pole"))
        self.remove_pole_button.setText(_translate("IPF", "Remove Pole"))
        self.remove_plane_button.setText(_translate("IPF", "Remove Plane"))
        self.add_plane_button.setText(_translate("IPF", "Add Plane"))
        self.refresh_Button.setText(_translate("IPF", "Update view"))
        self.green_Button.setText(_translate("IPF", "Green"))
        self.draw_button.setText(_translate("IPF", "Draw Standard Triangle"))
        self.PF_button.setText(_translate("IPF", "plot PF"))
        self.IPF_button.setText(_translate("IPF", "plot IPF"))
        self.import_button.setText(_translate("IPF", "Import data"))
        self.current_checkBox.setText(_translate("IPF", "curr. orientation"))
