# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'xyzUI.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_xyz_dialog(object):
    def setupUi(self, xyz_dialog):
        xyz_dialog.setObjectName("xyz_dialog")
        xyz_dialog.resize(396, 234)
        self.gridLayoutWidget = QtWidgets.QWidget(xyz_dialog)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(10, 10, 381, 218))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.Y_label = QtWidgets.QLabel(self.gridLayoutWidget)
        self.Y_label.setObjectName("Y_label")
        self.gridLayout.addWidget(self.Y_label, 3, 0, 1, 2)
        self.Z_label = QtWidgets.QLabel(self.gridLayoutWidget)
        self.Z_label.setObjectName("Z_label")
        self.gridLayout.addWidget(self.Z_label, 6, 0, 2, 2)
        self.X_label = QtWidgets.QLabel(self.gridLayoutWidget)
        self.X_label.setObjectName("X_label")
        self.gridLayout.addWidget(self.X_label, 0, 0, 1, 1)
        self.xyz_button = QtWidgets.QPushButton(self.gridLayoutWidget)
        self.xyz_button.setObjectName("xyz_button")
        self.gridLayout.addWidget(self.xyz_button, 10, 0, 1, 1)
        self.uvw_CheckBox = QtWidgets.QCheckBox(self.gridLayoutWidget)
        self.uvw_CheckBox.setObjectName("uvw_CheckBox")
        self.gridLayout.addWidget(self.uvw_CheckBox, 10, 1, 1, 1)
        self.X_text = QtWidgets.QLineEdit(self.gridLayoutWidget)
        self.X_text.setObjectName("X_text")
        self.gridLayout.addWidget(self.X_text, 1, 0, 2, 2)
        self.Y_text = QtWidgets.QLineEdit(self.gridLayoutWidget)
        self.Y_text.setObjectName("Y_text")
        self.gridLayout.addWidget(self.Y_text, 4, 0, 2, 2)
        self.Z_text = QtWidgets.QLineEdit(self.gridLayoutWidget)
        self.Z_text.setObjectName("Z_text")
        self.gridLayout.addWidget(self.Z_text, 8, 0, 2, 2)

        self.retranslateUi(xyz_dialog)
        QtCore.QMetaObject.connectSlotsByName(xyz_dialog)
        xyz_dialog.setTabOrder(self.X_text, self.Y_text)
        xyz_dialog.setTabOrder(self.Y_text, self.Z_text)
        xyz_dialog.setTabOrder(self.Z_text, self.xyz_button)

    def retranslateUi(self, xyz_dialog):
        _translate = QtCore.QCoreApplication.translate
        xyz_dialog.setWindowTitle(_translate("xyz_dialog", "xyz directions"))
        self.Y_label.setText(_translate("xyz_dialog", "Y"))
        self.Z_label.setText(_translate("xyz_dialog", "Z"))
        self.X_label.setText(_translate("xyz_dialog", "X"))
        self.xyz_button.setText(_translate("xyz_dialog", "Update"))
        self.uvw_CheckBox.setText(_translate("xyz_dialog", "uvw"))
