# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'kikuchi.ui'
#
# Created by: PyQt5 UI code generator 5.14.1
#
# WARNING! All changes made in this file will be lost!


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Kikuchi(object):
    def setupUi(self, Kikuchi):
        Kikuchi.setObjectName("Kikuchi")
        Kikuchi.setWindowModality(QtCore.Qt.NonModal)
        Kikuchi.resize(830, 818)
        self.layoutWidget = QtWidgets.QWidget(Kikuchi)
        self.layoutWidget.setGeometry(QtCore.QRect(9, 9, 811, 801))
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.error_label = QtWidgets.QLabel(self.layoutWidget)
        self.error_label.setObjectName("error_label")
        self.gridLayout.addWidget(self.error_label, 3, 5, 1, 1)
        self.kikuchi_radioButton = QtWidgets.QRadioButton(self.layoutWidget)
        self.kikuchi_radioButton.setObjectName("kikuchi_radioButton")
        self.gridLayout.addWidget(self.kikuchi_radioButton, 4, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(self.layoutWidget)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 6, 0, 1, 9)
        self.diff_radioButton = QtWidgets.QRadioButton(self.layoutWidget)
        self.diff_radioButton.setObjectName("diff_radioButton")
        self.gridLayout.addWidget(self.diff_radioButton, 3, 0, 1, 1)
        self.t_label = QtWidgets.QLabel(self.layoutWidget)
        self.t_label.setObjectName("t_label")
        self.gridLayout.addWidget(self.t_label, 3, 3, 1, 1)
        self.E_label = QtWidgets.QLabel(self.layoutWidget)
        self.E_label.setObjectName("E_label")
        self.gridLayout.addWidget(self.E_label, 1, 0, 1, 1)
        self.t_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.t_entry.setObjectName("t_entry")
        self.gridLayout.addWidget(self.t_entry, 3, 4, 1, 1)
        self.mplwindow = QtWidgets.QWidget(self.layoutWidget)
        self.mplwindow.setObjectName("mplwindow")
        self.gridLayoutWidget = QtWidgets.QWidget(self.mplwindow)
        self.gridLayoutWidget.setGeometry(QtCore.QRect(0, 0, 801, 661))
        self.gridLayoutWidget.setObjectName("gridLayoutWidget")
        self.mplvl = QtWidgets.QGridLayout(self.gridLayoutWidget)
        self.mplvl.setContentsMargins(0, 0, 0, 0)
        self.mplvl.setObjectName("mplvl")
        self.gridLayout.addWidget(self.mplwindow, 0, 0, 1, 9)
        self.angle_label = QtWidgets.QLabel(self.layoutWidget)
        self.angle_label.setObjectName("angle_label")
        self.gridLayout.addWidget(self.angle_label, 1, 3, 1, 1)
        self.spot_size_label = QtWidgets.QLabel(self.layoutWidget)
        self.spot_size_label.setObjectName("spot_size_label")
        self.gridLayout.addWidget(self.spot_size_label, 1, 5, 1, 1)
        self.angle_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.angle_entry.setObjectName("angle_entry")
        self.gridLayout.addWidget(self.angle_entry, 1, 4, 1, 1)
        self.spot_size_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.spot_size_entry.setObjectName("spot_size_entry")
        self.gridLayout.addWidget(self.spot_size_entry, 1, 6, 1, 1)
        self.label_checkBox = QtWidgets.QCheckBox(self.layoutWidget)
        self.label_checkBox.setObjectName("label_checkBox")
        self.gridLayout.addWidget(self.label_checkBox, 1, 7, 1, 2)
        self.error_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.error_entry.setObjectName("error_entry")
        self.gridLayout.addWidget(self.error_entry, 3, 6, 1, 1)
        self.indices_label = QtWidgets.QLabel(self.layoutWidget)
        self.indices_label.setObjectName("indices_label")
        self.gridLayout.addWidget(self.indices_label, 3, 1, 1, 1)
        self.indices_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.indices_entry.setObjectName("indices_entry")
        self.gridLayout.addWidget(self.indices_entry, 3, 2, 1, 1)
        self.E_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.E_entry.setObjectName("E_entry")
        self.gridLayout.addWidget(self.E_entry, 1, 1, 1, 1)
        self.Diff_button = QtWidgets.QPushButton(self.layoutWidget)
        self.Diff_button.setObjectName("Diff_button")
        self.gridLayout.addWidget(self.Diff_button, 3, 7, 2, 2)

        self.retranslateUi(Kikuchi)
        QtCore.QMetaObject.connectSlotsByName(Kikuchi)
        Kikuchi.setTabOrder(self.E_entry, self.angle_entry)
        Kikuchi.setTabOrder(self.angle_entry, self.spot_size_entry)
        Kikuchi.setTabOrder(self.spot_size_entry, self.label_checkBox)
        Kikuchi.setTabOrder(self.label_checkBox, self.diff_radioButton)
        Kikuchi.setTabOrder(self.diff_radioButton, self.indices_entry)
        Kikuchi.setTabOrder(self.indices_entry, self.t_entry)
        Kikuchi.setTabOrder(self.t_entry, self.error_entry)
        Kikuchi.setTabOrder(self.error_entry, self.Diff_button)
        Kikuchi.setTabOrder(self.Diff_button, self.kikuchi_radioButton)
        Kikuchi.setTabOrder(self.kikuchi_radioButton, self.buttonBox)

    def retranslateUi(self, Kikuchi):
        _translate = QtCore.QCoreApplication.translate
        Kikuchi.setWindowTitle(_translate("Kikuchi", "Kikuchi lines / Diffraction pattern"))
        self.error_label.setText(_translate("Kikuchi", "Excitation error (nm-1)"))
        self.kikuchi_radioButton.setText(_translate("Kikuchi", "Kikuchi"))
        self.diff_radioButton.setText(_translate("Kikuchi", "Diffraction"))
        self.t_label.setText(_translate("Kikuchi", "Thickness (nm)"))
        self.E_label.setText(_translate("Kikuchi", "E (kV)"))
        self.angle_label.setText(_translate("Kikuchi", "Aperture angle"))
        self.spot_size_label.setText(_translate("Kikuchi", "Spot size"))
        self.label_checkBox.setText(_translate("Kikuchi", "labels"))
        self.indices_label.setText(_translate("Kikuchi", "Max indices"))
        self.Diff_button.setText(_translate("Kikuchi", "Diff calc."))
