# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'kikuchiUI.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets
import os
fn = os.path.join(os.path.dirname(__file__), "kikuchi-icon.png")


class Ui_Kikuchi(object):
    def setupUi(self, Kikuchi):
        Kikuchi.setObjectName("Kikuchi")
        Kikuchi.resize(1213, 783)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(fn), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        Kikuchi.setWindowIcon(icon)
        self.centralwidget = QtWidgets.QWidget(Kikuchi)
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_7 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_7.setObjectName("gridLayout_7")
        self.groupBox_2 = QtWidgets.QGroupBox(self.centralwidget)
        self.groupBox_2.setMaximumSize(QtCore.QSize(350, 16777215))
        self.groupBox_2.setTitle("")
        self.groupBox_2.setObjectName("groupBox_2")
        self.gridLayout = QtWidgets.QGridLayout(self.groupBox_2)
        self.gridLayout.setObjectName("gridLayout")
        self.groupBox_9 = QtWidgets.QGroupBox(self.groupBox_2)
        self.groupBox_9.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox_9.setObjectName("groupBox_9")
        self.gridLayout_10 = QtWidgets.QGridLayout(self.groupBox_9)
        self.gridLayout_10.setObjectName("gridLayout_10")
        self.Button_addband = QtWidgets.QPushButton(self.groupBox_9)
        self.Button_addband.setEnabled(True)
        self.Button_addband.setObjectName("Button_addband")
        self.gridLayout_10.addWidget(self.Button_addband, 2, 3, 1, 1)
        self.ListBox_d_2 = QtWidgets.QListWidget(self.groupBox_9)
        self.ListBox_d_2.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.ListBox_d_2.sizePolicy().hasHeightForWidth())
        self.ListBox_d_2.setSizePolicy(sizePolicy)
        self.ListBox_d_2.setMaximumSize(QtCore.QSize(16777215, 100))
        self.ListBox_d_2.setObjectName("ListBox_d_2")
        self.gridLayout_10.addWidget(self.ListBox_d_2, 2, 0, 2, 3)
        self.Button_remove_band = QtWidgets.QPushButton(self.groupBox_9)
        self.Button_remove_band.setObjectName("Button_remove_band")
        self.gridLayout_10.addWidget(self.Button_remove_band, 3, 3, 1, 1)
        self.ListBox_theo = QtWidgets.QListWidget(self.groupBox_9)
        self.ListBox_theo.setObjectName("ListBox_theo")
        self.gridLayout_10.addWidget(self.ListBox_theo, 13, 0, 2, 4)
        self.plot_bands_button = QtWidgets.QPushButton(self.groupBox_9)
        self.plot_bands_button.setObjectName("plot_bands_button")
        self.gridLayout_10.addWidget(self.plot_bands_button, 4, 3, 1, 1)
        self.Button_add_center = QtWidgets.QPushButton(self.groupBox_9)
        self.Button_add_center.setObjectName("Button_add_center")
        self.gridLayout_10.addWidget(self.Button_add_center, 0, 0, 1, 2)
        self.centerLine = QtWidgets.QLineEdit(self.groupBox_9)
        self.centerLine.setObjectName("centerLine")
        self.gridLayout_10.addWidget(self.centerLine, 0, 2, 1, 2)
        self.label = QtWidgets.QLabel(self.groupBox_9)
        self.label.setObjectName("label")
        self.gridLayout_10.addWidget(self.label, 4, 0, 1, 1)
        self.tol_entry = QtWidgets.QLineEdit(self.groupBox_9)
        self.tol_entry.setObjectName("tol_entry")
        self.gridLayout_10.addWidget(self.tol_entry, 4, 1, 1, 1)
        self.Button_run = QtWidgets.QPushButton(self.groupBox_9)
        font = QtGui.QFont()
        font.setBold(True)
        font.setWeight(75)
        self.Button_run.setFont(font)
        self.Button_run.setObjectName("Button_run")
        self.gridLayout_10.addWidget(self.Button_run, 12, 0, 1, 4)
        self.Button_orientation = QtWidgets.QPushButton(self.groupBox_9)
        self.Button_orientation.setObjectName("Button_orientation")
        self.gridLayout_10.addWidget(self.Button_orientation, 15, 0, 1, 4)
        self.gridLayout.addWidget(self.groupBox_9, 2, 0, 2, 5)
        self.groupBox = QtWidgets.QGroupBox(self.groupBox_2)
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 16777215))
        self.groupBox.setObjectName("groupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.groupBox)
        self.gridLayout_2.setContentsMargins(5, 5, 5, 5)
        self.gridLayout_2.setSpacing(5)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.Button_reset = QtWidgets.QPushButton(self.groupBox)
        self.Button_reset.setObjectName("Button_reset")
        self.gridLayout_2.addWidget(self.Button_reset, 25, 0, 1, 6)
        self.a_label = QtWidgets.QLabel(self.groupBox)
        self.a_label.setObjectName("a_label")
        self.gridLayout_2.addWidget(self.a_label, 0, 0, 1, 1)
        self.abc_entry = QtWidgets.QLineEdit(self.groupBox)
        self.abc_entry.setObjectName("abc_entry")
        self.gridLayout_2.addWidget(self.abc_entry, 0, 2, 1, 1)
        self.d_label_var = QtWidgets.QLabel(self.groupBox)
        self.d_label_var.setText("")
        self.d_label_var.setObjectName("d_label_var")
        self.gridLayout_2.addWidget(self.d_label_var, 9, 5, 1, 1)
        self.alpha_label = QtWidgets.QLabel(self.groupBox)
        self.alpha_label.setObjectName("alpha_label")
        self.gridLayout_2.addWidget(self.alpha_label, 9, 0, 1, 1)
        self.indice_label = QtWidgets.QLabel(self.groupBox)
        self.indice_label.setObjectName("indice_label")
        self.gridLayout_2.addWidget(self.indice_label, 14, 0, 1, 1)
        self.space_group_label = QtWidgets.QLabel(self.groupBox)
        self.space_group_label.setObjectName("space_group_label")
        self.gridLayout_2.addWidget(self.space_group_label, 15, 0, 1, 1)
        self.brightness_label = QtWidgets.QLabel(self.groupBox)
        self.brightness_label.setObjectName("brightness_label")
        self.gridLayout_2.addWidget(self.brightness_label, 16, 0, 1, 1)
        self.alphabetagamma_entry = QtWidgets.QLineEdit(self.groupBox)
        self.alphabetagamma_entry.setObjectName("alphabetagamma_entry")
        self.gridLayout_2.addWidget(self.alphabetagamma_entry, 9, 2, 1, 1)
        self.indice_entry = QtWidgets.QLineEdit(self.groupBox)
        self.indice_entry.setObjectName("indice_entry")
        self.gridLayout_2.addWidget(self.indice_entry, 14, 2, 1, 1)
        self.space_group_Box = QtWidgets.QComboBox(self.groupBox)
        self.space_group_Box.setObjectName("space_group_Box")
        self.gridLayout_2.addWidget(self.space_group_Box, 15, 2, 1, 1)
        self.brightness_slider = QtWidgets.QSlider(self.groupBox)
        self.brightness_slider.setOrientation(QtCore.Qt.Horizontal)
        self.brightness_slider.setObjectName("brightness_slider")
        self.gridLayout_2.addWidget(self.brightness_slider, 16, 2, 1, 1)
        self.Calib_label = QtWidgets.QLabel(self.groupBox)
        self.Calib_label.setObjectName("Calib_label")
        self.gridLayout_2.addWidget(self.Calib_label, 19, 0, 1, 1)
        self.Calib_box = QtWidgets.QComboBox(self.groupBox)
        self.Calib_box.setObjectName("Calib_box")
        self.gridLayout_2.addWidget(self.Calib_box, 19, 2, 1, 1)
        self.reset_view_button = QtWidgets.QPushButton(self.groupBox)
        self.reset_view_button.setObjectName("reset_view_button")
        self.gridLayout_2.addWidget(self.reset_view_button, 26, 0, 1, 6)
        self.gridLayout.addWidget(self.groupBox, 1, 0, 1, 1)
        self.gridLayout_7.addWidget(self.groupBox_2, 0, 2, 1, 1)
        self.mplvl = QtWidgets.QGridLayout()
        self.mplvl.setObjectName("mplvl")
        self.gridLayout_7.addLayout(self.mplvl, 0, 1, 1, 1)
        Kikuchi.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(Kikuchi)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 1213, 22))
        self.menubar.setObjectName("menubar")
        self.menuSave = QtWidgets.QMenu(self.menubar)
        self.menuSave.setObjectName("menuSave")
        self.menuStructure = QtWidgets.QMenu(self.menubar)
        self.menuStructure.setObjectName("menuStructure")
        self.menuRefine = QtWidgets.QMenu(self.menubar)
        self.menuRefine.setObjectName("menuRefine")
        Kikuchi.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(Kikuchi)
        self.statusbar.setObjectName("statusbar")
        Kikuchi.setStatusBar(self.statusbar)
        self.actionSave_figure = QtWidgets.QAction(Kikuchi)
        self.actionSave_figure.setObjectName("actionSave_figure")
        self.actionCalculate_Schmid_factor = QtWidgets.QAction(Kikuchi)
        self.actionCalculate_Schmid_factor.setObjectName("actionCalculate_Schmid_factor")
        self.actionCalculate_spectrum = QtWidgets.QAction(Kikuchi)
        self.actionCalculate_spectrum.setObjectName("actionCalculate_spectrum")
        self.actionRefine_orientation = QtWidgets.QAction(Kikuchi)
        self.actionRefine_orientation.setObjectName("actionRefine_orientation")
        self.actionGet_orientation_at_zero_tilt = QtWidgets.QAction(Kikuchi)
        self.actionGet_orientation_at_zero_tilt.setObjectName("actionGet_orientation_at_zero_tilt")
        self.actionTilt = QtWidgets.QAction(Kikuchi)
        self.actionTilt.setObjectName("actionTilt")
        self.menuSave.addAction(self.actionSave_figure)
        self.menuRefine.addAction(self.actionRefine_orientation)
        self.menuRefine.addAction(self.actionTilt)
        self.menubar.addAction(self.menuSave.menuAction())
        self.menubar.addAction(self.menuStructure.menuAction())
        self.menubar.addAction(self.menuRefine.menuAction())

        self.retranslateUi(Kikuchi)
        QtCore.QMetaObject.connectSlotsByName(Kikuchi)
        Kikuchi.setTabOrder(self.abc_entry, self.alphabetagamma_entry)
        Kikuchi.setTabOrder(self.alphabetagamma_entry, self.indice_entry)
        Kikuchi.setTabOrder(self.indice_entry, self.space_group_Box)
        Kikuchi.setTabOrder(self.space_group_Box, self.brightness_slider)
        Kikuchi.setTabOrder(self.brightness_slider, self.Calib_box)
        Kikuchi.setTabOrder(self.Calib_box, self.Button_reset)
        Kikuchi.setTabOrder(self.Button_reset, self.reset_view_button)
        Kikuchi.setTabOrder(self.reset_view_button, self.Button_add_center)
        Kikuchi.setTabOrder(self.Button_add_center, self.centerLine)
        Kikuchi.setTabOrder(self.centerLine, self.ListBox_d_2)
        Kikuchi.setTabOrder(self.ListBox_d_2, self.Button_addband)
        Kikuchi.setTabOrder(self.Button_addband, self.Button_remove_band)
        Kikuchi.setTabOrder(self.Button_remove_band, self.tol_entry)
        Kikuchi.setTabOrder(self.tol_entry, self.plot_bands_button)
        Kikuchi.setTabOrder(self.plot_bands_button, self.Button_run)
        Kikuchi.setTabOrder(self.Button_run, self.ListBox_theo)
        Kikuchi.setTabOrder(self.ListBox_theo, self.Button_orientation)

    def retranslateUi(self, Kikuchi):
        _translate = QtCore.QCoreApplication.translate
        Kikuchi.setWindowTitle(_translate("Kikuchi", "Kikuchi"))
        self.groupBox_9.setTitle(_translate("Kikuchi", "Bands"))
        self.Button_addband.setText(_translate("Kikuchi", "Add bands"))
        self.Button_remove_band.setText(_translate("Kikuchi", "Remove band"))
        self.plot_bands_button.setText(_translate("Kikuchi", "Plot bands"))
        self.Button_add_center.setText(_translate("Kikuchi", "Add center"))
        self.label.setText(_translate("Kikuchi", "tol. angle"))
        self.Button_run.setText(_translate("Kikuchi", "Run"))
        self.Button_orientation.setText(_translate("Kikuchi", "Show bands"))
        self.groupBox.setTitle(_translate("Kikuchi", "Crystal Parameters"))
        self.Button_reset.setText(_translate("Kikuchi", "Reset points"))
        self.a_label.setText(_translate("Kikuchi", "a,b,c"))
        self.alpha_label.setText(_translate("Kikuchi", "<html><head/><body><p>α,β,γ  </p></body></html>"))
        self.indice_label.setText(_translate("Kikuchi", "Max Indices"))
        self.space_group_label.setText(_translate("Kikuchi", "Space group"))
        self.brightness_label.setText(_translate("Kikuchi", "Brightness"))
        self.Calib_label.setText(_translate("Kikuchi", "Calibrations"))
        self.reset_view_button.setText(_translate("Kikuchi", "Reset view"))
        self.menuSave.setTitle(_translate("Kikuchi", "Open"))
        self.menuStructure.setTitle(_translate("Kikuchi", "Structure"))
        self.menuRefine.setTitle(_translate("Kikuchi", "Tools"))
        self.actionSave_figure.setText(_translate("Kikuchi", "Open image"))
        self.actionCalculate_Schmid_factor.setText(_translate("Kikuchi", "calculate Schmid factor"))
        self.actionCalculate_spectrum.setText(_translate("Kikuchi", "Plot spectrum"))
        self.actionRefine_orientation.setText(_translate("Kikuchi", "Refine orientation"))
        self.actionGet_orientation_at_zero_tilt.setText(_translate("Kikuchi", "get orientation at zero-tilt"))
        self.actionTilt.setText(_translate("Kikuchi", "Tilt conditions"))
