# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'angleUI.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Angle(object):
    def setupUi(self, Angle):
        Angle.setObjectName("Angle")
        Angle.resize(285, 234)
        self.layoutWidget = QtWidgets.QWidget(Angle)
        self.layoutWidget.setGeometry(QtCore.QRect(10, 10, 266, 216))
        self.layoutWidget.setObjectName("layoutWidget")
        self.gridLayout = QtWidgets.QGridLayout(self.layoutWidget)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.buttonBox = QtWidgets.QDialogButtonBox(self.layoutWidget)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 7, 0, 1, 2)
        self.angle_label = QtWidgets.QLabel(self.layoutWidget)
        self.angle_label.setText("")
        self.angle_label.setObjectName("angle_label")
        self.gridLayout.addWidget(self.angle_label, 6, 0, 1, 2)
        self.n2_label = QtWidgets.QLabel(self.layoutWidget)
        self.n2_label.setObjectName("n2_label")
        self.gridLayout.addWidget(self.n2_label, 3, 0, 1, 1)
        self.n1_label = QtWidgets.QLabel(self.layoutWidget)
        self.n1_label.setObjectName("n1_label")
        self.gridLayout.addWidget(self.n1_label, 0, 0, 1, 1)
        self.n2_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.n2_entry.setObjectName("n2_entry")
        self.gridLayout.addWidget(self.n2_entry, 4, 0, 2, 1)
        self.n1_entry = QtWidgets.QLineEdit(self.layoutWidget)
        self.n1_entry.setObjectName("n1_entry")
        self.gridLayout.addWidget(self.n1_entry, 1, 0, 2, 1)
        self.uvw1_button = QtWidgets.QCheckBox(self.layoutWidget)
        self.uvw1_button.setObjectName("uvw1_button")
        self.gridLayout.addWidget(self.uvw1_button, 1, 1, 2, 1)
        self.uvw2_button = QtWidgets.QCheckBox(self.layoutWidget)
        self.uvw2_button.setObjectName("uvw2_button")
        self.gridLayout.addWidget(self.uvw2_button, 4, 1, 2, 1)

        self.retranslateUi(Angle)
        QtCore.QMetaObject.connectSlotsByName(Angle)
        Angle.setTabOrder(self.n1_entry, self.n2_entry)
        Angle.setTabOrder(self.n2_entry, self.buttonBox)

    def retranslateUi(self, Angle):
        _translate = QtCore.QCoreApplication.translate
        Angle.setWindowTitle(_translate("Angle", "Angle"))
        self.n2_label.setText(_translate("Angle", "n2/d2"))
        self.n1_label.setText(_translate("Angle", "n1/d1"))
        self.uvw1_button.setText(_translate("Angle", "uvw"))
        self.uvw2_button.setText(_translate("Angle", "uvw"))
