# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'DrawInterfaceUI.ui'
#
# Created by: PyQt5 UI code generator 5.10.1
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_Draw_plane_directions(object):
    def setupUi(self, Draw_plane_directions):
        Draw_plane_directions.setObjectName("Draw_plane_directions")
        Draw_plane_directions.resize(399, 281)
        self.gridLayout_2 = QtWidgets.QGridLayout(Draw_plane_directions)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.gridLayout = QtWidgets.QGridLayout()
        self.gridLayout.setObjectName("gridLayout")
        self.plane_label = QtWidgets.QLabel(Draw_plane_directions)
        self.plane_label.setObjectName("plane_label")
        self.gridLayout.addWidget(self.plane_label, 2, 0, 2, 1)
        self.surf_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.surf_checkBox.setObjectName("surf_checkBox")
        self.gridLayout.addWidget(self.surf_checkBox, 1, 3, 1, 1)
        self.label_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.label_checkBox.setObjectName("label_checkBox")
        self.gridLayout.addWidget(self.label_checkBox, 4, 0, 1, 1)
        self.surface_label = QtWidgets.QLabel(Draw_plane_directions)
        self.surface_label.setObjectName("surface_label")
        self.gridLayout.addWidget(self.surface_label, 1, 0, 1, 1)
        self.buttonBox = QtWidgets.QDialogButtonBox(Draw_plane_directions)
        self.buttonBox.setStandardButtons(QtWidgets.QDialogButtonBox.Cancel|QtWidgets.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName("buttonBox")
        self.gridLayout.addWidget(self.buttonBox, 7, 0, 1, 4)
        self.thickness_label = QtWidgets.QLabel(Draw_plane_directions)
        self.thickness_label.setObjectName("thickness_label")
        self.gridLayout.addWidget(self.thickness_label, 0, 0, 1, 1)
        self.hexa_Button = QtWidgets.QCheckBox(Draw_plane_directions)
        self.hexa_Button.setObjectName("hexa_Button")
        self.gridLayout.addWidget(self.hexa_Button, 4, 3, 1, 1)
        self.measure_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.measure_checkBox.setObjectName("measure_checkBox")
        self.gridLayout.addWidget(self.measure_checkBox, 4, 1, 1, 1)
        self.measure_label = QtWidgets.QLabel(Draw_plane_directions)
        self.measure_label.setText("")
        self.measure_label.setTextInteractionFlags(QtCore.Qt.LinksAccessibleByMouse|QtCore.Qt.TextSelectableByMouse)
        self.measure_label.setObjectName("measure_label")
        self.gridLayout.addWidget(self.measure_label, 6, 0, 1, 4)
        self.thickness_entry = QtWidgets.QLineEdit(Draw_plane_directions)
        self.thickness_entry.setObjectName("thickness_entry")
        self.gridLayout.addWidget(self.thickness_entry, 0, 1, 1, 2)
        self.surface_entry = QtWidgets.QLineEdit(Draw_plane_directions)
        self.surface_entry.setObjectName("surface_entry")
        self.gridLayout.addWidget(self.surface_entry, 1, 1, 1, 2)
        self.proj_image_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.proj_image_checkBox.setObjectName("proj_image_checkBox")
        self.gridLayout.addWidget(self.proj_image_checkBox, 5, 0, 1, 1)
        self.scale_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.scale_checkBox.setObjectName("scale_checkBox")
        self.gridLayout.addWidget(self.scale_checkBox, 5, 3, 1, 1)
        self.scale_entry = QtWidgets.QLineEdit(Draw_plane_directions)
        self.scale_entry.setObjectName("scale_entry")
        self.gridLayout.addWidget(self.scale_entry, 5, 2, 1, 1)
        self.plane_entry = QtWidgets.QLineEdit(Draw_plane_directions)
        self.plane_entry.setObjectName("plane_entry")
        self.gridLayout.addWidget(self.plane_entry, 2, 1, 2, 2)
        self.dir_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.dir_checkBox.setObjectName("dir_checkBox")
        self.gridLayout.addWidget(self.dir_checkBox, 2, 3, 1, 1)
        self.inv_checkBox = QtWidgets.QCheckBox(Draw_plane_directions)
        self.inv_checkBox.setObjectName("inv_checkBox")
        self.gridLayout.addWidget(self.inv_checkBox, 3, 3, 1, 1)
        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)

        self.retranslateUi(Draw_plane_directions)
        QtCore.QMetaObject.connectSlotsByName(Draw_plane_directions)
        Draw_plane_directions.setTabOrder(self.thickness_entry, self.surface_entry)
        Draw_plane_directions.setTabOrder(self.surface_entry, self.surf_checkBox)
        Draw_plane_directions.setTabOrder(self.surf_checkBox, self.plane_entry)
        Draw_plane_directions.setTabOrder(self.plane_entry, self.dir_checkBox)
        Draw_plane_directions.setTabOrder(self.dir_checkBox, self.inv_checkBox)
        Draw_plane_directions.setTabOrder(self.inv_checkBox, self.label_checkBox)
        Draw_plane_directions.setTabOrder(self.label_checkBox, self.measure_checkBox)
        Draw_plane_directions.setTabOrder(self.measure_checkBox, self.hexa_Button)
        Draw_plane_directions.setTabOrder(self.hexa_Button, self.proj_image_checkBox)
        Draw_plane_directions.setTabOrder(self.proj_image_checkBox, self.scale_entry)
        Draw_plane_directions.setTabOrder(self.scale_entry, self.scale_checkBox)

    def retranslateUi(self, Draw_plane_directions):
        _translate = QtCore.QCoreApplication.translate
        Draw_plane_directions.setWindowTitle(_translate("Draw_plane_directions", "Draw planes-directions"))
        self.plane_label.setText(_translate("Draw_plane_directions", "Plane/Direction"))
        self.surf_checkBox.setText(_translate("Draw_plane_directions", "surf."))
        self.label_checkBox.setText(_translate("Draw_plane_directions", "label"))
        self.surface_label.setText(_translate("Draw_plane_directions", "Surface norm."))
        self.thickness_label.setText(_translate("Draw_plane_directions", "Thickness (nm)"))
        self.hexa_Button.setText(_translate("Draw_plane_directions", "hexa"))
        self.measure_checkBox.setText(_translate("Draw_plane_directions", "measure"))
        self.proj_image_checkBox.setText(_translate("Draw_plane_directions", "proj. image"))
        self.scale_checkBox.setText(_translate("Draw_plane_directions", "scale (nm)"))
        self.dir_checkBox.setText(_translate("Draw_plane_directions", "dir."))
        self.inv_checkBox.setText(_translate("Draw_plane_directions", "inv"))

